#
# spec file for package tagsoup
#
# Copyright (c) 2024 SUSE LLC
# Copyright (c) 2000-2005, JPackage Project
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           tagsoup
Version:        1.2.1
Release:        6.2
Summary:        A SAX-compliant HTML parser written in Java
License:        Apache-2.0
Group:          Productivity/Publishing/XML
URL:            http://home.ccil.org/~cowan/XML/tagsoup/
#Source0:        http://home.ccil.org/~cowan/XML/tagsoup/tagsoup-1.2.1-src.zip
Source0:        tagsoup-1.2.1-src.zip
Source1:        https://repo1.maven.org/maven2/org/ccil/cowan/tagsoup/%{name}/%{version}/%{name}-%{version}.pom
Patch0:         tagsoup-1.2.1-man.patch
Patch1:         tagsoup-1.2.1-jdk9.patch
BuildRequires:  ant
BuildRequires:  fdupes
BuildRequires:  java-devel >= 1.8
BuildRequires:  javapackages-local >= 6
BuildRequires:  unzip
BuildRequires:  xalan-j2
Requires:       javapackages-tools
BuildArch:      noarch

%description
TagSoup is a SAX-compliant parser written in Java that, instead of
parsing well-formed or valid XML, parses HTML as it is found in the wild: nasty
and brutish, though quite often far from short. By providing a SAX interface,
it allows standard XML tools to be applied to even the worst HTML.

%package javadoc
Summary:        Javadoc for %{name}
Group:          Documentation/HTML

%description javadoc
Javadoc package for %{name}.

%prep
%setup -q
%patch -P 0
%patch -P 1 -p1

find . -name '*.class' -delete
find . -name "*.jar" -delete

%build
export CLASSPATH=$(build-classpath xalan-j2-serializer xalan-j2)
ant \
  -Dant.build.javac.source=1.8 -Dant.build.javac.target=1.8 \
  -Dtagsoup.version=%{version} \
  -Dj2se.apiurl=%{_javadocdir}/java \
  -Dclasspath=$(build-classpath xalan-j2-serializer xalan-j2) \
  dist docs-api

%install
# jar
mkdir -p %{buildroot}%{_javadir}
install -m 644 dist/lib/%{name}-%{version}.jar \
  %{buildroot}%{_javadir}/%{name}.jar
# pom
mkdir -p %{buildroot}%{_mavenpomdir}
%{mvn_install_pom} %{SOURCE1} %{buildroot}%{_mavenpomdir}/JPP-%{name}.pom
%add_maven_depmap
# javadoc
mkdir -p %{buildroot}%{_javadocdir}/%{name}
cp -pr docs/api/* %{buildroot}%{_javadocdir}/%{name}
%fdupes -s %{buildroot}%{_javadocdir}/%{name}

mkdir -p %{buildroot}%{_mandir}/man1
install -m 644 %{name}.1 %{buildroot}%{_mandir}/man1/

%files -f .mfiles
%{_mandir}/man1/%{name}.1%{?ext_man}
%license LICENSE
%doc CHANGES README TODO %{name}.txt

%files javadoc
%{_javadocdir}/%{name}

%changelog
* Wed Feb 21 2024 Fridrich Strba <fstrba@suse.com>
- Use %%patch -P N instead of deprecated %%patchN.
* Sat Aug  6 2022 Fridrich Strba <fstrba@suse.com>
- Condition for SLE-12 to avoid accidental use of modular java
  with javapackages-tools 2.x
* Sun Mar 20 2022 Fridrich Strba <fstrba@suse.com>
- Compile with source and target levels 8
* Sat Feb  9 2019 Fridrich Strba <fstrba@suse.com>
- Not only install the pom, but also generate maven metadata so
  so that the artifact can be used
* Thu Sep 21 2017 fstrba@suse.com
- Fix build with jdk9: specify source and target level 1.6
- Added patch:
  * tagsoup-1.2.1-jdk9.patch
    + Don't specify java source and target levels on command-line
  + Give path to the built classes to javadoc
* Mon Jul 10 2017 jengelh@inai.de
- Ensure neutrality of description.
* Fri Jun 23 2017 fstrba@suse.com
- Initial commit of tagsoup-1.2.1, based on Fedora package
